/*
 * Copyright © 2020-2023 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of gaming-core.
 *
 * Gaming-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Gaming-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * gaming-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.core.domain;

import java.util.Map;

import de.fhdw.gaming.core.ui.InputProvider;
import de.fhdw.gaming.core.ui.InputProviderException;
import de.fhdw.gaming.core.ui.util.NonInteractiveInputProvider;

/**
 * Allows to create an {@link Observer}.
 */
public interface ObserverFactory {

    /**
     * Returns the name of the {@link ObserverFactory}.
     */
    String getName();

    /**
     * Creates an {@link Observer} object.
     *
     * @param parameters The parameters for the observer.
     */
    Observer createObserver(Map<String, Object> parameters);

    /**
     * Creates an {@link Observer} object with default parameters.
     */
    default Observer createObserver() throws InputProviderException {
        return this.createObserver(this.getInputProvider(
                new NonInteractiveInputProvider()).requestData(this.getName()));
    }

    /**
     * Allows to customise an {@link InputProvider} for retrieving needed parameters.
     *
     * @param inputProvider The {@link InputProvider} to customise.
     * @return The customised {@link InputProvider}.
     */
    default InputProvider getInputProvider(final InputProvider inputProvider) throws InputProviderException {
        return inputProvider;
    }
}
