/*
 * Copyright © 2020-2023 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of gaming-core.
 *
 * Gaming-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Gaming-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * gaming-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.core.ui;

import java.util.ArrayList;
import java.util.List;
import java.util.ServiceLoader;

/**
 * Allows to create an {@link InputProvider}..
 */
public interface InputProviderFactory {

    /**
     * Creates an {@link InputProvider} object.
     */
    InputProvider createInputProvider();

    /**
     * Returns all available observer factories.
     */
    static List<InputProviderFactory> getInstances() {
        final ServiceLoader<InputProviderFactory> services = ServiceLoader.load(InputProviderFactory.class);
        final List<InputProviderFactory> list = new ArrayList<>();
        services.iterator().forEachRemaining(list::add);
        return list;
    }
}
