package de.fhdw.gaming.core.ui.type.validator;

import java.util.regex.Pattern;

import de.fhdw.gaming.core.ui.InputProviderException;

/**
 * Validates against a regular expression.
 */
public final class PatternValidator implements Validator<String> {

    /**
     * The regular expression.
     */
    private final Pattern pattern;

    /**
     * Creates a {@link PatternValidator}.
     *
     * @param pattern The regular expression.
     */
    public PatternValidator(final Pattern pattern) {
        this.pattern = pattern;
    }

    @Override
    public String validate(final String value) throws InputProviderException {
        if (!this.pattern.matcher(value).matches()) {
            throw new InputProviderException(this.getInfo());
        } else {
            return value;
        }
    }

    @Override
    public String getInfo() {
        return String.format("The value must match the regular expression '%s'.", this.pattern);
    }
}
