package de.fhdw.gaming.core.ui.type.validator;

import java.util.Optional;
import java.util.Set;

import de.fhdw.gaming.core.ui.InputProviderException;

/**
 * Validates against a set of allowed values.
 *
 * @param <T> The type of value.
 */
public final class ValueSetValidator<T> implements Validator<T> {

    /**
     * The set containing the values allowed.
     */
    private final Set<? extends T> allowedValues;

    /**
     * Creates a {@link ValueSetValidator}.
     *
     * @param allowedValues The set containing the values allowed.
     */
    public ValueSetValidator(final Set<? extends T> allowedValues) {
        this.allowedValues = allowedValues;
    }

    @Override
    public T validate(final T value) throws InputProviderException {
        final Optional<
                ? extends T> object = this.allowedValues.stream().filter((final T o) -> o.equals(value)).findFirst();

        if (object.isEmpty()) {
            throw new InputProviderException(this.getInfo());
        }
        return object.get();
    }

    @Override
    public String getInfo() {
        return String.format("The value must be one of %s.", this.allowedValues);
    }
}
